#' Average temperature
#'
#' Average monthly temperature in Paris.
#'
#' @format Time series data
#' @source Makridakis, Wheelwright and Hyndman (1998) \emph{Forecasting:
#' methods and applications}, John Wiley & Sons: New York. Exercise 2.1.
#' @keywords datasets
#' @examples
#' plot(paris)
#' seasonplot(paris)
#' tsdisplay(paris)
#'
"paris"
